# pylint: disable=wildcard-import

from logging import CRITICAL, DEBUG, ERROR, INFO, WARNING

from .helpers import *
from .logger import *

WARN = WARNING

d = debug
i = info
w = warn = warning
e = error
c = critical
exc = exception
